==> pymdown-extensions-4.1.tar.gz: pymdown-extensions-4.1/docs/src/markdown/_snippets/links.md <==
[abbreviations]: https://pythonhosted.org/Markdown/extensions/abbreviations.html
[aspell]: http://aspell.net/
[attr-list]: https://pythonhosted.org/Markdown/extensions/attr_list.html
[bleach]: https://pypi.python.org/pypi/bleach
[codehilite]: https://pythonhosted.org/Markdown/extensions/code_hilite.html
[coverage]: https://coverage.readthedocs.io
[critic-markup]: http://criticmarkup.com/
[def-list]: https://pythonhosted.org/Markdown/extensions/definition_lists.html
[emojione]: https://github.com/Ranks/emojione
[emojione-awesome-css]: https://github.com/Ranks/emojione/blob/master/extras/css/emojione-awesome.css
[emojione-sprites-svg]: https://github.com/Ranks/emojione/blob/v2.2.7/assets/sprites/emojione.sprites.svg
[flake8]: https://pypi.python.org/pypi/flake8
[flake8-docstrings]: https://pypi.python.org/pypi/flake8-docstrings
[flowchart-js]: http://adrai.github.io/flowchart.js/
[footnotes]: https://pythonhosted.org/Markdown/extensions/footnotes.html
[gemoji]: https://github.com/github/gemoji
[github-api-emoji]: https://developer.github.com/v3/emojis/
[github-api-oauth]: https://developer.github.com/v3/oauth/
[highlightjs]: https://highlightjs.org/
[mathjax]: http://www.mathjax.org/
[mkdocs]: https://github.com/mkdocs/mkdocs
[mkdocs-material]: https://github.com/squidfunk/mkdocs-material
[nested-markdown]: https://pythonhosted.org/Markdown/extensions/extra.html#nested-markdown-inside-html-blocks
[nl2br]: https://pythonhosted.org/Markdown/extensions/nl2br.html
[octicons]: https://octicons.github.com/
[pep8-naming]: https://pypi.python.org/pypi/pep8-naming
[pygments]: http://pygments.org/
[pymdown-styles]: https://github.com/facelessuser/pymdown-styles/tree/master/pymdown_styles
[pytest]: http://doc.pytest.org/en/latest/
[python-markdown]: https://github.com/waylan/Python-Markdown
[raphael-js]: http://dmitrybaranovskiy.github.io/raphael/
[requests]: https://pypi.python.org/pypi/requests/
[sequence-diagram-js]: http://bramp.github.io/js-sequence-diagrams/
[tables]: https://pythonhosted.org/Markdown/extensions/tables.html
[toc]: https://pythonhosted.org/Markdown/extensions/toc.html
[tox]: https://pypi.python.org/pypi/tox
[twemoji]: https://github.com/twitter/twemoji
[underscore-js]: http://underscorejs.org/
[unicode-norm]: http://unicode.org/reports/tr15/#Norm_Forms

==> pymdown-extensions-4.3.tar.gz: pymdown-extensions-4.3/docs/src/markdown/_snippets/links.md <==
[abbreviations]: https://pythonhosted.org/Markdown/extensions/abbreviations.html
[aspell]: http://aspell.net/
[attr-list]: https://pythonhosted.org/Markdown/extensions/attr_list.html
[bleach]: https://pypi.python.org/pypi/bleach
[codehilite]: https://pythonhosted.org/Markdown/extensions/code_hilite.html
[coverage]: https://coverage.readthedocs.io
[critic-markup]: http://criticmarkup.com/
[def-list]: https://pythonhosted.org/Markdown/extensions/definition_lists.html
[emojione]: https://github.com/Ranks/emojione
[emojione-awesome-css]: https://github.com/Ranks/emojione/blob/master/extras/css/emojione-awesome.css
[emojione-sprites-svg]: https://github.com/Ranks/emojione/blob/v2.2.7/assets/sprites/emojione.sprites.svg
[flake8]: https://pypi.python.org/pypi/flake8
[flake8-docstrings]: https://pypi.python.org/pypi/flake8-docstrings
[flowchart-js]: http://adrai.github.io/flowchart.js/
[footnotes]: https://pythonhosted.org/Markdown/extensions/footnotes.html
[gemoji]: https://github.com/github/gemoji
[github-api-emoji]: https://developer.github.com/v3/emojis/
[github-api-oauth]: https://developer.github.com/v3/oauth/
[highlightjs]: https://highlightjs.org/
[mathjax]: http://www.mathjax.org/
[mkdocs]: https://github.com/mkdocs/mkdocs
[mkdocs-material]: https://github.com/squidfunk/mkdocs-material
[nested-markdown]: https://pythonhosted.org/Markdown/extensions/extra.html#nested-markdown-inside-html-blocks
[nl2br]: https://pythonhosted.org/Markdown/extensions/nl2br.html
[octicons]: https://octicons.github.com/
[pep8-naming]: https://pypi.python.org/pypi/pep8-naming
[pygments]: http://pygments.org/
[pymdown-styles]: https://github.com/facelessuser/pymdown-styles/tree/master/pymdown_styles
[pytest]: http://doc.pytest.org/en/latest/
[python-markdown]: https://github.com/Python-Markdown/markdown
[raphael-js]: http://dmitrybaranovskiy.github.io/raphael/
[requests]: https://pypi.python.org/pypi/requests/
[sequence-diagram-js]: http://bramp.github.io/js-sequence-diagrams/
[tables]: https://pythonhosted.org/Markdown/extensions/tables.html
[toc]: https://pythonhosted.org/Markdown/extensions/toc.html
[tox]: https://pypi.python.org/pypi/tox
[twemoji]: https://github.com/twitter/twemoji
[underscore-js]: http://underscorejs.org/
[unicode-norm]: http://unicode.org/reports/tr15/#Norm_Forms
